@@ -57,6 +57,8 @@ class SmartAdminSite(AdminSite):
 
     def each_context(self, request):
         context = super().each_context(request)
+        context['site_title'] = str(self.site_title)
+        context['site_header'] = str(self.site_header)
         context['groups'] = dict(self._get_menu(request)[0])
         context['sysinfo'] = self.sysinfo_url
         context['smart_settings'] = smart_settings
@@ -73,6 +75,10 @@ class SmartAdminSite(AdminSite):
 
         return context
 
+    def reverse_object_url(self, obj, page):
+        url_name = '%s:%s_%s_%s' % (self.name, obj._meta.app_label, obj._meta.model_name, page)
+        return reverse(url_name)
+
     def register_panel(self, callable, url_name=None, label=None):
         if not label:
             label = getattr(callable, 'verbose_name', callable.__name__.title())
